return {
  { -- Fuzzy Finder (files, lsp, etc)
    'nvim-telescope/telescope.nvim',
    event = 'VimEnter',
    branch = '0.1.x',
    dependencies = {
      'nvim-lua/plenary.nvim',
      { -- If encountering errors, see telescope-fzf-native README for install instructions
        'nvim-telescope/telescope-fzf-native.nvim',
        build = 'make',
        cond = function()
          return vim.fn.executable 'make' == 1
        end,
      },
      { 'nvim-telescope/telescope-ui-select.nvim' },


      -- change directory with telescope from a list of directories
      {
        "SalOrak/whaler",
        opts = {
          directories = { "/home/lupan/src" },
          oneoff_directories = { "/home/lupan/dotfiles" },
          auto_file_explorer = false,
          auto_cwd = true,
        }
      },

      -- Icons, requires Nerd font.
      { 'nvim-tree/nvim-web-devicons' },

      'davvid/telescope-git-grep.nvim',
    },
    config = function()
      local telescope = require 'telescope'
      -- To list available key bindings inside given telescope picker:
      --  - Insert mode: <c-/>
      --  - Normal mode: ?
      telescope.setup {
        extensions = {
          ['ui-select'] = {
            require('telescope.themes').get_dropdown(),
          },
          whaler = {
            directories = { "/home/lupan/src" },
            oneoff_directories = { "/home/lupan/dotfiles" },
            auto_file_explorer = false,
            auto_cwd = true,
          }
        },
      }

      pcall(telescope.load_extension, 'fzf')
      pcall(telescope.load_extension, 'ui-select')
      pcall(telescope.load_extension, 'whaler')
      pcall(telescope.load_extension, 'git_grep')
      pcall(telescope.load_extension, 'persisted')

      -- See `:help telescope.builtin`
      local builtin = require 'telescope.builtin'
      vim.keymap.set('n', '<leader>sf', builtin.find_files, { desc = '[S]earch [F]iles' })
      vim.keymap.set('n', '<leader>sT', builtin.builtin, { desc = '[S]earch [S]elect Telescope' })
      vim.keymap.set('n', '<leader>sW', builtin.grep_string, { desc = '[S]earch current [W]ord' })
      vim.keymap.set('n', '<leader>sr', builtin.resume, { desc = '[S]earch [R]esume' })

      vim.keymap.set('n', '<leader>s.', builtin.oldfiles, { desc = '[S]earch Recent Files ("." for repeat)' })
      vim.keymap.set('n', '<leader>sL', function() telescope.extensions.whaler.whaler() end,
        { desc = '[S]earch with wha[L]er' })
      vim.keymap.set('n', '<leader>gw', function() telescope.extensions.git_grep.grep() end,
        { desc = '[G]it grep current [W]ord' })
    end,
  }

}
